==> openmetadata_ingestion-1.9.11.3.tar.gz: openmetadata_ingestion-1.9.11.3/src/metadata/ingestion/source/database/snowflake/constants.py <==
#  Copyright 2025 Collate
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
"""
Snowflake constants
"""

from sqlalchemy.sql.sqltypes import BOOLEANTYPE, VARCHAR

DEFAULT_STREAM_COLUMNS = [
    {
        "name": "METADATA$ACTION",
        "type": VARCHAR(length=16777216),
        "nullable": True,
        "default": None,
        "autoincrement": False,
        "system_data_type": "TEXT(16777216)",
        "comment": None,
        "primary_key": False,
    },
    {
        "name": "METADATA$ISUPDATE",
        "type": BOOLEANTYPE,
        "nullable": True,
        "default": None,
        "autoincrement": False,
        "system_data_type": "BOOLEAN",
        "comment": None,
        "primary_key": False,
    },
    {
        "name": "METADATA$ROW_ID",
        "type": VARCHAR(length=16777216),
        "nullable": True,
        "default": None,
        "autoincrement": False,
        "system_data_type": "TEXT(16777216)",
        "comment": None,
        "primary_key": False,
    },
]

SNOWFLAKE_TAG_DESCRIPTION = "SNOWFLAKE TAG VALUE"
SNOWFLAKE_CLASSIFICATION_DESCRIPTION = "SNOWFLAKE TAG NAME"

==> openmetadata_ingestion-1.9.12.0.tar.gz: openmetadata_ingestion-1.9.12.0/src/metadata/ingestion/source/database/snowflake/constants.py <==
#  Copyright 2025 Collate
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
"""
Snowflake constants
"""

from sqlalchemy.sql.sqltypes import BOOLEANTYPE, VARCHAR

from metadata.generated.schema.entity.data.storedProcedure import StoredProcedureType
from metadata.generated.schema.entity.data.table import TableType

DEFAULT_STREAM_COLUMNS = [
    {
        "name": "METADATA$ACTION",
        "type": VARCHAR(length=16777216),
        "nullable": True,
        "default": None,
        "autoincrement": False,
        "system_data_type": "TEXT(16777216)",
        "comment": None,
        "primary_key": False,
    },
    {
        "name": "METADATA$ISUPDATE",
        "type": BOOLEANTYPE,
        "nullable": True,
        "default": None,
        "autoincrement": False,
        "system_data_type": "BOOLEAN",
        "comment": None,
        "primary_key": False,
    },
    {
        "name": "METADATA$ROW_ID",
        "type": VARCHAR(length=16777216),
        "nullable": True,
        "default": None,
        "autoincrement": False,
        "system_data_type": "TEXT(16777216)",
        "comment": None,
        "primary_key": False,
    },
]

SNOWFLAKE_TAG_DESCRIPTION = "SNOWFLAKE TAG VALUE"
SNOWFLAKE_CLASSIFICATION_DESCRIPTION = "SNOWFLAKE TAG NAME"

TABLE_TYPE_URL_MAP = {
    TableType.Regular: "table",
    TableType.Transient: "table",
    TableType.Dynamic: "dynamic-table",
    TableType.External: "external-table",
    TableType.View: "view",
    TableType.MaterializedView: "materialized-view",
    TableType.Stream: "stream",
}

PROCEDURE_TYPE_URL_MAP = {
    StoredProcedureType.StoredProcedure: "procedure",
    StoredProcedureType.UDF: "user-function",
}
